@@ -4,7 +4,9 @@
 #include "global.h"
 #include "Info.hpp"
 
-
+namespace cURLpp
+{
+	
 template< >
 void
 cURLpp::InfoTypeConverter< std::string >::get(cURLpp::Easy &handle, 
@@ -34,3 +36,5 @@ cURLpp::InfoTypeConverter< long >::get(cURLpp::Easy &,
 {
   
 }
+
+}; /*namespace cURLpp */
